@@ -1,7 +1,6 @@
 import pika
 import sys
 import os
-import argparse
 import json
 import requests
 from pathlib import Path
@@ -73,9 +72,8 @@ class Connection:
 
     def set_route(self):
         try:
-            logger.info(f'Connecting Pika to {RABBITMQ_HOST}' +
-                        'at port {RABBITMQ_PORT}'
-                        )
+            logger.info(
+                f'Connecting Pika to {RABBITMQ_HOST} at port {RABBITMQ_PORT}')
             self.connection = pika.BlockingConnection(
                 pika.ConnectionParameters(
                     host=RABBITMQ_HOST, port=RABBITMQ_PORT)
@@ -84,9 +82,8 @@ class Connection:
             self.channel.queue_declare(queue=self.choosen_method)
             # self.channel.queue_declare(queue=f"{queue_name}.results")
         except Exception as ex:
-            logger.error(f'Connecting Pika to {RABBITMQ_HOST}' +
-                         'at port {RABBITMQ_PORT}'
-                         )
+            logger.error(
+                f'Connecting Pika to {RABBITMQ_HOST} at port {RABBITMQ_PORT}')
             logger.exception(ex)
             logger.critical("Aborting...")
             exit()
@@ -109,14 +106,15 @@ class Connection:
                 # PROCESS VIDEO
                 requests.patch(
                     url=UPDATE_URL+message.get("liveness_id")+"/",
-                    headers=header,
+                    headers={"Authorization": "asdf"},
                     json={
-                        f'{self.choosen_method}_status:' +
-                        LivenessStatusEnum.processing.name},
+                        f'{self.choosen_method}_status': LivenessStatusEnum.processing.name}
+                    # {f'{self.choosen_method}_status:'+LivenessStatusEnum.processing.name},
+
                 )
                 logger.info("Starting Liveness method: {}".format(
                     self.choosen_method))
-                answer = self.current_method.analyseVideo(pth)
+                answer = self.current_method.analyse_video(pth)
 
                 print(answer)
                 logger.info(
